{"thread":{"id":"31449","subject":"git-svn: memoize cmt_metadata","startedAt":"2012-09-05T18:25:51Z","lastAt":"2012-09-05T18:25:51Z","messageCount":1,"participants":["Lalit Chhabra"],"isPatch":false,"patchVersion":null,"patchTotal":null},"messages":[{"id":"198394","messageId":"20120905182552.11530@gmx.com","threadId":"31449","inReplyTo":null,"subject":"git-svn: memoize cmt_metadata","fromName":"Lalit Chhabra","fromEmail":"lchhabra@linuxmail.org","sentAt":"2012-09-05T18:25:51Z","receivedAt":"2012-09-05T18:25:51Z","isPatch":false,"sender":{"key":"lchhabra@linuxmail.org","avatar":null},"body":"Hi,\n\n I have about 150 \"branches = ...\" and \"tags = ...\" lines in my\n .git/config file, and I see a 30x improvement in 'git svn rebase -l'\n when I memoize the cmt_metadata function. (The run time goes\n down from ~150 seconds to ~5 seconds on my machine).\n\n I see that it was memoized in version:\n * c1927a8 2006-06-27 | git-svn: several graft-branches improvements\n\n and then removed in version:\n * 396988e 2007-01-13 | git-svn: get rid of Memoize for now...\n\n Is it safe to re-memoize this function?\n\n Thanks,\n Lalit Chhabra\n"}]}